/*
 * MinIO Cloud Storage, (C) 2018 MinIO, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package policy

import (
	"testing"
)

func TestEffectIsAllowed(t *testing.T) {
	testCases := []struct {
		effect         Effect
		check          bool
		expectedResult bool
	}{
		{Allow, false, false},
		{Allow, true, true},
		{Deny, false, true},
		{Deny, true, false},
	}

	for i, testCase := range testCases {
		result := testCase.effect.IsAllowed(testCase.check)

		if result != testCase.expectedResult {
			t.Fatalf("case %v: expected: %v, got: %v\n", i+1, testCase.expectedResult, result)
		}
	}

}

func TestEffectIsValid(t *testing.T) {
	testCases := []struct {
		effect         Effect
		expectedResult bool
	}{
		{Allow, true},
		{Deny, true},
		{Effect(""), false},
		{Effect("foo"), false},
	}

	for i, testCase := range testCases {
		result := testCase.effect.IsValid()

		if result != testCase.expectedResult {
			t.Fatalf("case %v: expected: %v, got: %v\n", i+1, testCase.expectedResult, result)
		}
	}
}
